@@ -48,4 +48,4 @@ def emit(name, values, tags=None):
         metric.add_tag(tag, tags[tag])
     for value in values:
         metric.add_value(value, values[value])
-    metrics_pipe.write(metric)
+    metrics_pipe.write(str(metric))
